@@ -104,13 +104,32 @@ check_args <- function(
 ) {
   if (rlang::is_missing(arg)) {
     if (use_data) {
+      x <- x[!is.na(x)]
+      if (is.numeric(x)) {
+        x <- x[is.finite(x)]
+      }
+      num_unique <- length(unique(x))
+
+      if (length(x) == 0) {
+        cli::cli_abort(
+          "The data must have at least on finite and non-missing value.",
+          call = call
+        )
+      }
       type <- rlang::arg_match0(
         type,
         c("low", "high", "target"),
         error_call = call
       )
       .fn <- switch(type, low = min, high = max, target = stats::median)
-      arg <- .fn(x, na.rm = TRUE)
+      arg <- .fn(x)
+      if (num_unique == 1) {
+        if (type == "low") {
+          arg <- arg -  2 * .Machine$double.eps
+        } else if (type == "high") {
+          arg <- arg +  2 * .Machine$double.eps
+        }
+      }
     } else {
       cli::cli_abort(
         "In {.fn {fn}}, argument {.arg {type}} is required when
