@@ -11,6 +11,12 @@
 #' @keywords internal
 "_PACKAGE"
 
+# enable usage of <S7_object>@name in package code
+#' @rawNamespace if (getRversion() < "4.3.0") importFrom("S7", "@")
+#'
 ## usethis namespace: start
+#' @import rlang
 ## usethis namespace: end
 NULL
+
+utils::globalVariables(".d_overall")
